@@ -238,6 +238,45 @@ bruvo.dist <- function(pop, replen = 1, add = TRUE, loss = TRUE, by_locus = FALS
   return(dist.mat)
 }
 
+#==============================================================================#
+#' @describeIn bruvo.dist Bruvo's distance between a query and a reference
+#' Only diferences between query individuals and reference individuals will be reported
+#' All other values are NaN
+#' 
+#' @param query a \code{\link{genind}} or \code{\link{genclone}} object
+#' 
+#' @param ref a \code{\link{genind}} or \code{\link{genclone}} object
+#' 
+#' @export
+#' @author David Folarin
+#==============================================================================#
+bruvo.between <- function(query, ref, replen = 1, add = TRUE, loss = TRUE, by_locus = FALSE){
+  pop <- repool(query, ref)
+  query_length <- dim(query@tab)[1]
+  # This attempts to make sure the data is true microsatellite data. It will
+  # reject snp and aflp data. 
+  if (pop@type != "codom" || all(is.na(unlist(lapply(alleles(pop), as.numeric))))){
+    stop(non_ssr_data_warning())
+  }
+  # Bruvo's distance depends on the knowledge of the repeat length. If the user
+  # does not provide the repeat length, it can be estimated by the smallest
+  # repeat difference greater than 1. This is not a preferred method. 
+  if (length(replen) < nLoc(pop)){
+    replen <- vapply(alleles(pop), function(x) guesslengths(as.numeric(x)), 1)
+    warning(repeat_length_warning(replen), immediate. = TRUE)
+    if (interactive()) Sys.sleep(2L)
+  }
+  bruvomat  <- new('bruvomat', pop, replen)
+  funk_call <- match.call()
+  if (length(add) != 1 || !is.logical(add) || length(loss) != 1 || !is.logical(loss)){
+    stop("add and loss flags must be either TRUE or FALSE. Please check your input.")
+  }
+  dist.mat <- bruvos_between(bruvomat, query_length, funk_call = funk_call, add, loss, by_locus)
+  if (by_locus){
+    names(dist.mat) <- locNames(pop)
+  }
+  return(dist.mat)
+}
 
 #==============================================================================#
 #
@@ -445,7 +484,7 @@ bruvo.boot <- function(pop, replen = 1, add = TRUE, loss = TRUE, sample = 100,
 #'   different populations containing the same multilocus genotype.}
 #'   
 #' @details The minimum spanning network generated by this function is generated
-#'   via igraph's \code{\link[igraph]{minimum.spanning.tree}}. The resultant
+#'   via igraph's \code{\link[igraph:mst]{minimum.spanning.tree}}. The resultant
 #'   graph produced can be plotted using igraph functions, or the entire object
 #'   can be plotted using the function \code{\link{plot_poppr_msn}}, which will
 #'   give the user a scale bar and the option to layout your data.
@@ -479,7 +518,7 @@ bruvo.boot <- function(pop, replen = 1, add = TRUE, loss = TRUE, sample = 100,
 #'   }
 #'   
 #' @seealso \code{\link{bruvo.dist}}, \code{\link{nancycats}}, 
-#'   \code{\link{plot_poppr_msn}}, \code{\link[igraph]{minimum.spanning.tree}} 
+#'   \code{\link{plot_poppr_msn}}, \code{\link[igraph]{mst}} 
 #'   \code{\link{bruvo.boot}}, \code{\link{greycurve}} \code{\link{poppr.msn}}
 #'   
 #' @export
@@ -536,7 +575,7 @@ bruvo.boot <- function(pop, replen = 1, add = TRUE, loss = TRUE, sample = 100,
 bruvo.msn <- function (gid, replen = 1, add = TRUE, loss = TRUE, 
                        mlg.compute = "original", 
                        palette = topo.colors,
-                       sublist = "All", blacklist = NULL, vertex.label = "MLG", 
+                       sublist = "All", exclude = NULL, blacklist = NULL, vertex.label = "MLG", 
                        gscale = TRUE, glim = c(0,0.8), gadj = 3, gweight = 1, 
                        wscale = TRUE, showplot = TRUE, 
                        include.ties = FALSE, threshold = NULL, 
@@ -551,6 +590,19 @@ bruvo.msn <- function (gid, replen = 1, add = TRUE, loss = TRUE,
   if (!inherits(gid@mlg, "MLG")){
     gid@mlg <- new("MLG", gid@mlg)
   }
+  if (!is.null(blacklist)) {
+    warning(
+      option_deprecated(
+        match.call(), 
+        "blacklist", 
+        "exclude", 
+        "2.8.7.", 
+        "Please use `exclude` in the future"
+       ), 
+      immediate. = TRUE
+    )
+    exclude <- blacklist
+  }
   
   
   
@@ -572,8 +624,8 @@ bruvo.msn <- function (gid, replen = 1, add = TRUE, loss = TRUE,
   
   gadj <- ifelse(gweight == 1, gadj, -gadj)
 
-  if (toupper(sublist[1]) != "ALL" | !is.null(blacklist)){
-    gid <- popsub(gid, sublist, blacklist)
+  if (toupper(sublist[1]) != "ALL" | !is.null(exclude)){
+    gid <- popsub(gid, sublist, exclude)
   }
 
   # Updating the MLG with filtered data
