@@ -202,9 +202,11 @@ poppr.plot <- function(sample, pval = c(Ia = 0.05, rbarD = 0.05),
 #' @param sublist a \code{vector} of population names or indexes that the user 
 #'   wishes to keep. Default to "ALL".
 #'   
-#' @param blacklist a \code{vector} of population names or indexes that the user
-#'   wishes to discard. Default to \code{NULL}
-#'   
+#' @param exclude a \code{vector} of population names or indexes that the user
+#' wishes to discard. Default to \code{NULL}.
+#'
+#' @param blacklist DEPRECATED, use exclude.
+#'
 #' @param vertex.label a \code{vector} of characters to label each vertex. There
 #'   are two defaults: \code{"MLG"} will label the nodes with the multilocus 
 #'   genotype from the original data set and \code{"inds"} will label the nodes 
@@ -265,7 +267,7 @@ poppr.plot <- function(sample, pval = c(Ia = 0.05, rbarD = 0.05),
 #'   
 #'   
 #' @details The minimum spanning network generated by this function is generated
-#'   via igraph's \code{\link[igraph]{minimum.spanning.tree}}. The resultant
+#'   via igraph's \code{\link[igraph:mst]{minimum.spanning.tree}}. The resultant
 #'   graph produced can be plotted using igraph functions, or the entire object
 #'   can be plotted using the function \code{\link{plot_poppr_msn}}, which will
 #'   give the user a scale bar and the option to layout your data.
@@ -354,7 +356,7 @@ poppr.plot <- function(sample, pval = c(Ia = 0.05, rbarD = 0.05),
 #' 
 #==============================================================================#
 poppr.msn <- function (gid, distmat, palette = topo.colors, mlg.compute = "original",
-                       sublist = "All", blacklist = NULL, vertex.label = "MLG", 
+                       sublist = "All", exclude = NULL, blacklist = NULL, vertex.label = "MLG", 
                        gscale=TRUE, glim = c(0,0.8), gadj = 3, gweight = 1, 
                        wscale=TRUE, showplot = TRUE, 
                        include.ties = FALSE, threshold = NULL, 
@@ -373,6 +375,19 @@ poppr.msn <- function (gid, distmat, palette = topo.colors, mlg.compute = "origi
   if (!inherits(gid@mlg, "MLG")){
     gid@mlg <- new("MLG", gid@mlg)
   }
+  if (!is.null(blacklist)) {
+    warning(
+      option_deprecated(
+        match.call(), 
+        "blacklist", 
+        "exclude", 
+        "2.8.7.", 
+        "Please use `exclude` in the future"
+       ), 
+      immediate. = TRUE
+    )
+    exclude <- blacklist
+  }
   
   
   # Handling MLG type -------------------------------------------------------
@@ -408,10 +423,10 @@ poppr.msn <- function (gid, distmat, palette = topo.colors, mlg.compute = "origi
   
   # Subsetting the population -----------------------------------------------
   # This will subset both the population and the matrix. 
-  if (toupper(sublist[1]) != "ALL" | !is.null(blacklist)){
-    sublist_blacklist <- sub_index(gid, sublist, blacklist)
-    distmat <- distmat[sublist_blacklist, sublist_blacklist, drop = FALSE]
-    gid    <- popsub(gid, sublist, blacklist)
+  if (toupper(sublist[1]) != "ALL" | !is.null(exclude)){
+    sublist_exclude <- sub_index(gid, sublist, exclude)
+    distmat <- distmat[sublist_exclude, sublist_exclude, drop = FALSE]
+    gid    <- popsub(gid, sublist, exclude)
   }
 
   # Clone correcting the matrix ---------------------------------------------
@@ -764,7 +779,7 @@ greycurve <- function(data = seq(0, 1, length = 1000), glim = c(0,0.8),
 #'   palette was used to produce the original graph.
 #'   
 #' @param layfun a function specifying the layout of nodes in your graph. It 
-#'   defaults to \code{\link[igraph]{layout.auto}}.
+#'   defaults to \code{\link[igraph:layout_nicely]{layout.auto}}.
 #'   
 #' @param beforecut if \code{TRUE}, the layout of the graph will be computed 
 #'   before any edges are removed with \code{cutoff}. If \code{FALSE} (Default),
@@ -842,9 +857,9 @@ greycurve <- function(data = seq(0, 1, length = 1000), glim = c(0,0.8),
 #' 
 #' @return the modified msn list, invisibly. 
 #' 
-#' @seealso \code{\link[igraph]{layout.auto}} \code{\link[igraph]{plot.igraph}}
+#' @seealso \code{\link[igraph:layout_nicely]{layout.auto}} \code{\link[igraph]{plot.igraph}}
 #' \code{\link{poppr.msn}} \code{\link{bruvo.msn}} \code{\link{greycurve}}
-#' \code{\link[igraph]{delete.edges}} \code{\link{palette}}
+#' \code{\link[igraph]{delete_edges}} \code{\link{palette}}
 #' 
 #' @author Zhian N. Kamvar
 #' @export
@@ -912,7 +927,7 @@ greycurve <- function(data = seq(0, 1, length = 1000), glim = c(0,0.8),
 #' ### Utilizing vectors for palettes
 #' 
 #' data(Pram)
-#' Pram_sub <- popsub(Pram, blacklist = c("Nursery_CA", "Nursery_OR"))
+#' Pram_sub <- popsub(Pram, exclude = c("Nursery_CA", "Nursery_OR"))
 #' 
 #' # Creating the network for the forest
 #' min_span_net_sub <- bruvo.msn(Pram_sub, replen = other(Pram)$REPLEN, 
@@ -1206,7 +1221,7 @@ plot_poppr_msn <- function(x,
 #' of multilocus genotypes observed.
 #' 
 #' @param gen a \code{\linkS4class{genclone}}, \code{\linkS4class{genind}}, or
-#'   \code{\link[pegas]{loci}} object.
+#'   \code{\link[pegas:read.loci]{loci}} object.
 #'   
 #' @param sample an \code{integer} defining the number of times loci will be 
 #'   resampled without replacement.
@@ -1239,7 +1254,7 @@ plot_poppr_msn <- function(x,
 #'   represent an independent sample.
 #'   
 #' @details Internally, this function works by converting the data into a 
-#'   \code{\link[pegas]{loci}} object, which represents genotypes as a data 
+#'   \code{\link[pegas:read.loci]{loci}} object, which represents genotypes as a data 
 #'   frame of factors. Random samples are taken of 1 to n-1 columns of the 
 #'   matrix and the number of unique rows are counted to determine the number of
 #'   multilocus genotypes in that random sample. This function does not take 
